.. image:: https://badge.fury.io/py/pyebus.svg
    :target: https://badge.fury.io/py/pyebus

.. image:: https://travis-ci.org/c0fec0de/pyebus.svg?branch=main
    :target: https://travis-ci.org/c0fec0de/pyebus

.. image:: https://coveralls.io/repos/github/c0fec0de/pyebus/badge.svg
    :target: https://coveralls.io/github/c0fec0de/pyebus

.. image:: https://codeclimate.com/github/c0fec0de/pyebus.png
    :target: https://codeclimate.com/github/c0fec0de/pyebus

.. image:: https://img.shields.io/pypi/pyversions/pyebus.svg
   :target: https://pypi.python.org/pypi/pyebus

.. image:: https://img.shields.io/badge/code%20style-pep8-brightgreen.svg
   :target: https://www.python.org/dev/peps/pep-0008/

.. image:: https://img.shields.io/badge/code%20style-pep257-brightgreen.svg
   :target: https://www.python.org/dev/peps/pep-0257/
